package com.link.core.objeccache;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.alibaba.fastjson.serializer.SimplePropertyPreFilter;
import com.link.core.basic.interceptor.SecurityInterceptor;
import com.link.core.basic.model.BasicModel;
import com.link.core.basic.query.Filter;
import com.link.core.basic.query.QueryParams;
import com.link.core.basic.service.BasicService;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.util.RedisUtil;
import com.link.core.util.ReflectUtil;
import com.link.core.util.SpringUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.redisclient.LinkRedisClient;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.core.env.Environment;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

public class ObjectCache {
   private static final Logger logger = LogManager.getLogger(ObjectCache.class);
   public static final ThreadLocal<String> redisKey = new ThreadLocal();
   public static final ThreadLocal<Integer> inputCacheExpire = new ThreadLocal();

   public static String genRedisKey() throws Exception {
      return (String)redisKey.get();
   }

   private static void checkParamMap(TreeMap<String, String> paramMap) throws Exception {
      if (paramMap.size() > 3) {
         throw new Exception("参数的字段不能超过3个！");
      } else if (paramMap.size() < 1) {
         throw new Exception("参数的字段不能为空！");
      } else {
         Iterator var1 = paramMap.entrySet().iterator();

         Map.Entry entry;
         do {
            if (!var1.hasNext()) {
               return;
            }

            entry = (Map.Entry)var1.next();
            if (StringUtils.isBlank((String)entry.getKey())) {
               throw new Exception("存在空字符串的key");
            }
         } while(!StringUtils.isBlank((String)entry.getValue()));

         throw new Exception("字段【" + (String)entry.getKey() + "】对应的值为空！");
      }
   }

   private static Map<String, String> queryByExamplePage(BasicService basicService, Class<? extends BasicModel> clz, TreeMap<String, String> paramMap, String queryFields, int configVersion, String redisDbName) throws Exception {
      return queryByExamplePage(basicService, clz, paramMap, queryFields, "", configVersion, redisDbName);
   }

   private static Map<String, String> queryByExamplePage(BasicService basicService, Class<? extends BasicModel> clz, TreeMap<String, String> paramMap, String queryFields, String from, int configVersion, String redisDbName) throws Exception {
      try {
         checkParamMap(paramMap);
         QueryParams qps = new QueryParams();
         String inputAdditionalParam = null;
         Iterator var9 = paramMap.entrySet().iterator();

         while(var9.hasNext()) {
            Map.Entry<String, String> entry = (Map.Entry)var9.next();
            if ("inputAdditionalParam".equals(entry.getKey())) {
               inputAdditionalParam = (String)entry.getValue();
            } else {
               qps.addFilter(new Filter((String)entry.getKey(), (String)entry.getKey(), "=", (String)entry.getValue()));
            }
         }

         BasicModel queryModel = BasicModel.transformClass(clz, qps);
         queryModel.setRows(5000);
         queryModel.setQueryFields(queryFields);
         if (StringUtils.isNotBlank(inputAdditionalParam)) {
            String[] inputAdditionalParamAttr = inputAdditionalParam.split(";");
            String[] var11 = inputAdditionalParamAttr;
            int var12 = inputAdditionalParamAttr.length;

            for(int var13 = 0; var13 < var12; ++var13) {
               String paramAdditional = var11[var13];
               String[] paramAdditionalAttr = paramAdditional.split(",");
               if (paramAdditionalAttr.length != 2) {
                  throw new Exception("传入的额外参数格式错误！");
               }

               ReflectUtil.invokeSetterNew(queryModel, paramAdditionalAttr[0], paramAdditionalAttr[1]);
            }
         }

         String modelName = clz.getName().substring(clz.getName().lastIndexOf(".") + 1);
         String redisKey = genRedisKey();
         Map<String, String> retMap = new HashMap(2);
         retMap.put("key", redisKey);
         String retStr = "";
         if (StringUtils.isBlank(from)) {
            retStr = RedisCache.getCacheValue(redisKey, basicService, queryModel, queryFields, clz, configVersion, redisDbName);
         } else if ("cache".equals(from)) {
            retStr = RedisCache.getCacheValueFromCache(redisKey, configVersion, redisDbName);
         } else if ("database".equals(from)) {
            retStr = RedisCache.getCacheValueFromDatabase(basicService, queryModel, queryFields, clz);
         }

         retMap.put("value", retStr);
         HashMap var25 = retMap;
         return var25;
      } finally {
         ObjectCache.redisKey.remove();
      }
   }

   private static Map<String, String> queryByExamplePage(String serviceName, TreeMap<String, String> paramMap, String queryFields, int configVersion, String redisDbName) throws Exception {
      return queryByExamplePage((BasicService)SpringUtil.getBean(serviceName), getServiceParamType(serviceName), paramMap, queryFields, configVersion, redisDbName);
   }

   public static Map<String, String> queryByExamplePage(String serviceName, TreeMap<String, String> paramMap, String queryFields, String from, int configVersion, String redisDbName) throws Exception {
      return queryByExamplePage((BasicService)SpringUtil.getBean(serviceName), getServiceParamType(serviceName), paramMap, queryFields, from, configVersion, redisDbName);
   }

   private static Map<String, String> queryById(BasicService serviceName, Class<? extends BasicModel> clz, Long value, String queryFields, int configVersion, String redisDbName) throws Exception {
      TreeMap<String, String> paramMap = new TreeMap();
      paramMap.put("id", String.valueOf(value));
      return queryByExamplePage(serviceName, clz, paramMap, queryFields, configVersion, redisDbName);
   }

   private static Map<String, String> queryById(String serviceName, Long value, String queryFields, int configVersion, String redisDbName) throws Exception {
      TreeMap<String, String> paramMap = new TreeMap();
      paramMap.put("id", String.valueOf(value));
      return queryByExamplePage((BasicService)SpringUtil.getBean(serviceName), getServiceParamType(serviceName), paramMap, queryFields, configVersion, redisDbName);
   }

   private static Class<? extends BasicModel> getServiceParamType(String serviceName) throws Exception {
      Class<?> superClass = SpringUtil.getBean(serviceName).getClass().getSuperclass();
      Type type = superClass.getGenericSuperclass();
      Class<? extends BasicModel> clz = null;
      if (type instanceof ParameterizedType) {
         ParameterizedType parameterizedType = (ParameterizedType)type;
         Type[] types = parameterizedType.getActualTypeArguments();
         clz = (Class)types[0];
         return clz;
      } else {
         throw new Exception("获取父类的泛型类型报错！");
      }
   }

   private static Map<String, String> queryFromOtherService(String modelName, String serviceName, TreeMap<String, String> paramMap, String queryFields, int configVersion, String redisDbName) throws Exception {
      return queryFromOtherService(modelName, serviceName, paramMap, queryFields, "", configVersion, redisDbName);
   }

   private static Map<String, String> queryFromOtherService(String modelName, String serviceName, TreeMap<String, String> paramMap, String queryFields, String from, int configVersion, String redisDbName) throws Exception {
      try {
         HttpHeaders headers = new HttpHeaders();
         headers.add("INNERTOKEN", (String)SecurityInterceptor.internal_token.get());
         headers.add("LinkRequestId", (String)SecurityInterceptor.linkRequestId.get());
         headers.add("Authorization", "bearer " + (String)SecurityInterceptor.token.get());
         MultiValueMap<String, String> requestBody = new LinkedMultiValueMap();
         requestBody.add("serviceName", serviceName);
         requestBody.add("paramMap", JSONObject.toJSONString(paramMap));
         requestBody.add("queryFields", queryFields);
         requestBody.add("from", from);
         requestBody.add("key", redisKey.get());
         requestBody.add("version", String.valueOf(configVersion));
         requestBody.add("redisDbName", redisDbName);
         HttpEntity<MultiValueMap<String, String>> request = new HttpEntity(requestBody, headers);
         RestTemplate restTemplate = (RestTemplate)SpringUtil.getBean(RestTemplate.class);
         String url = "http://" + modelName + "/link/objectCache/queryByExamplePage";
         ResponseEntity<JSONObject> response = restTemplate.postForEntity(url, request, JSONObject.class, new Object[0]);
         if (response.getStatusCode() != HttpStatus.OK) {
            throw new Exception("调用接口获取缓存报错！httpcode:" + response.getStatusCode());
         } else if (!((JSONObject)response.getBody()).getBoolean("success")) {
            throw new Exception(((JSONObject)response.getBody()).getString("result"));
         } else {
            Map<String, String> retMap = (Map)((JSONObject)response.getBody()).get("result");
            return retMap;
         }
      } catch (Exception var14) {
         Exception e = var14;
         throw e;
      }
   }

   public static int genVersionByConfCode(JSONObject jsonConfig) throws Exception {
      return jsonConfig.getInteger("version");
   }

   public static Map<String, String> queryByService(String micServiceName, String from, Map<String, String> valueMap, JSONObject jsonConfig) throws Exception {
      checkConfigValidity(jsonConfig);
      String genRedisKey = genRedisKeyByConf(jsonConfig, valueMap);
      int newVersion = genVersionByConfCode(jsonConfig);
      redisKey.set(genRedisKey);
      String queryCondition = jsonConfig.getString("queryCondition");
      String[] queryConditionAttr = queryCondition.split(":");
      String serviceName = queryConditionAttr[0];
      String modelName = queryConditionAttr[1];
      TreeMap<String, String> paramMap = getParamMap(valueMap, jsonConfig);
      String queryFileds = jsonConfig.getString("queryField");
      String redisDbName = jsonConfig.getString("redisDbName");
      return queryFromOtherService(micServiceName, serviceName, paramMap, queryFileds, from, newVersion, redisDbName);
   }

   private static TreeMap<String, String> getParamMap(Map<String, String> valueMap, JSONObject jsonConfig) throws Exception {
      String redisKey = jsonConfig.getString("preRedisKey");
      String queryCondition = jsonConfig.getString("queryCondition");
      String[] queryConditionAttr = queryCondition.split(":");
      TreeMap<String, String> paramMap = new TreeMap();

      for(int i = 2; i < queryConditionAttr.length; ++i) {
         if (!valueMap.containsKey(queryConditionAttr[i])) {
            throw new Exception("传入的查询条件中，字段缺失：" + queryConditionAttr[i]);
         }

         String value = (String)valueMap.get(queryConditionAttr[i]);
         paramMap.put(queryConditionAttr[i], value);
      }

      return paramMap;
   }

   private static String genRedisKeyByConf(JSONObject jsonConfig, Map<String, String> valueMap) throws Exception {
      String redisKey = jsonConfig.getString("preRedisKey");
      String queryCondition = jsonConfig.getString("queryCondition");
      String[] queryConditionAttr = queryCondition.split(":");

      for(int i = 2; i < queryConditionAttr.length; ++i) {
         if (!valueMap.containsKey(queryConditionAttr[i])) {
            throw new Exception("传入的查询条件中，字段缺失：" + queryConditionAttr[i]);
         }

         String value = (String)valueMap.get(queryConditionAttr[i]);
         redisKey = redisKey.concat(":").concat(value);
      }

      return redisKey;
   }

   public static String genRedisKeyByConfCode(String configCode, Map<String, String> valueMap) throws Exception {
      JSONObject jsonConfig = getConfigByKey(configCode);
      return genRedisKeyByConf(jsonConfig, valueMap);
   }

   public static String getCondition(String configCode) throws Exception {
      JSONObject jsonConfig = getConfigByKey(configCode);
      return jsonConfig.getString("queryCondition");
   }

   private static void checkConfigValidity(JSONObject jsonConfig) throws Exception {
      String preRedisKey = jsonConfig.getString("preRedisKey");
      if (StringUtils.isBlank(preRedisKey)) {
         throw new Exception("未维护rediskey的前缀");
      } else {
         String queryCondition = jsonConfig.getString("queryCondition");
         if (StringUtils.isBlank(queryCondition)) {
            throw new Exception("条件为空，请检查所维护的数据！");
         } else {
            String[] queryConditionAttr = queryCondition.split(":");
            if (queryConditionAttr.length < 3) {
               throw new Exception("所维护的条件格式出错！");
            }
         }
      }
   }

   public static Map<String, String> queryFromCache(String key, String from, Map<String, String> valueMap, String inputServiceName) throws Exception {
      JSONObject jsonConfig = getConfigByKey(key);
      String micServiceName = jsonConfig.getString("micServiceName");
      if (StringUtils.isNotBlank(inputServiceName)) {
         micServiceName = inputServiceName;
      }

      Environment environment = (Environment)SpringUtil.getBean(Environment.class);
      String curMicServiceName = environment.getProperty("spring.application.name");
      if (!curMicServiceName.equalsIgnoreCase(micServiceName)) {
         return queryByService(micServiceName, from, valueMap, jsonConfig);
      } else {
         checkConfigValidity(jsonConfig);
         String genRedisKey = genRedisKeyByConf(jsonConfig, valueMap);
         redisKey.set(genRedisKey);
         String queryCondition = jsonConfig.getString("queryCondition");
         String[] queryConditionAttr = queryCondition.split(":");
         String serviceName = queryConditionAttr[0];
         String modelName = queryConditionAttr[1];
         TreeMap<String, String> paramMap = getParamMap(valueMap, jsonConfig);
         String queryFileds = jsonConfig.getString("queryField");
         String redisDbName = jsonConfig.getString("redisDbName");
         int configVersion = genVersionByConfCode(jsonConfig);
         return queryByExamplePage(serviceName, paramMap, queryFileds, from, configVersion, redisDbName);
      }
   }

   public static Map<String, String> queryFromCache(String key, String from, Map<String, String> valueMap) throws Exception {
      return queryFromCache(key, from, valueMap, "");
   }

   public static Map<String, String> queryFromCache(String key, String from, Map<String, String> valueMap, Integer expire) throws Exception {
      Map var4;
      try {
         inputCacheExpire.set(expire);
         var4 = queryFromCache(key, from, valueMap);
      } finally {
         inputCacheExpire.remove();
      }

      return var4;
   }

   public static JSONObject getConfigByKey(String key) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         redisClient = RedisUtil.getJedis();
         JSONArray jsonArray = ObjectConfigCache.getObjectConfigCache();
         Iterator var3 = jsonArray.iterator();

         JSONObject jsonConfig;
         do {
            if (!var3.hasNext()) {
               throw new Exception("未维护当前key对应的配置：" + key);
            }

            Object object = var3.next();
            jsonConfig = (JSONObject)object;
         } while(!StringUtils.isNotBlank(jsonConfig.getString("code")) || !jsonConfig.getString("code").equals(key));

         JSONObject var6 = jsonConfig;
         return var6;
      } finally {
         RedisUtil.returnResource(redisClient);
      }
   }

   public static List<String> getConfigKey() throws Exception {
      LinkRedisClient redisClient = null;
      List<String> configKeyList = new ArrayList();

      try {
         redisClient = RedisUtil.getJedis();
         JSONArray jsonArray = ObjectConfigCache.getObjectConfigCache();
         Iterator var3 = jsonArray.iterator();

         while(var3.hasNext()) {
            Object object = var3.next();
            JSONObject jsonConfig = (JSONObject)object;
            if (StringUtils.isNotBlank(jsonConfig.getString("code"))) {
               configKeyList.add(jsonConfig.getString("code"));
            }
         }

         ArrayList var9 = configKeyList;
         return var9;
      } finally {
         RedisUtil.returnResource(redisClient);
      }
   }

   public static void afterUpByConfCode(List<String> confCodes, Object obj, String micServiceName, String addFlag) throws Exception {
      logger.info("通用缓存刷新内容：" + JSONObject.toJSONString(confCodes));
      Iterator var4 = confCodes.iterator();

      while(var4.hasNext()) {
         String confCode = (String)var4.next();
         LinkRedisClient redisClient = null;

         try {
            String queryField = getCondition(confCode);
            logger.info("通用缓存刷新获取的查询条件：" + queryField);
            Map<String, String> paramMap = transToMap(obj, queryField);
            JSONObject jsonConfig = getConfigByKey(confCode);
            String redisKey = genRedisKeyByConf(jsonConfig, paramMap);
            String redisDbName = jsonConfig.getString("redisDbName");
            redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
            logger.info("通用缓存刷新的key: {}, redis库：{}", redisKey, redisDbName);
            if (redisClient.exists(redisKey) || "Y".equals(addFlag)) {
               Map<String, String> memberMapStr = queryFromCache(confCode, "database", paramMap, micServiceName);
               String memberStr = (String)memberMapStr.get("value");
               int newVersion = genVersionByConfCode(jsonConfig);
               Map<String, Object> map = new HashMap();
               map.put("version", newVersion);
               map.put("list", memberStr);
               Long ttl = redisClient.ttl(redisKey);
               if (ttl > 0L) {
                  redisClient.setex(redisKey, Math.toIntExact(ttl), JSONObject.toJSONString(map));
               } else {
                  redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
               }
            }
         } finally {
            RedisUtil.returnResource(redisClient);
         }
      }

   }

   public static void afterUpByConfCode(List<String> confCodes, Object obj) throws Exception {
      afterUpByConfCode(confCodes, obj, "", "");
   }

   private static Map<String, String> transToMap(Object obj, String queryField) {
      Map<String, String> paramMap = new HashMap();

      try {
         String[] queryFields = queryField.split(":");

         for(int i = 2; i < queryFields.length; ++i) {
            Object value = ReflectUtil.invokeGetterNew(obj, queryFields[i]);
            if (value == null) {
               throw new Exception("查询条件" + queryFields[i] + "的值为空,刷新该对象的缓存失败！");
            }

            paramMap.put(queryFields[i], value.toString());
         }

         return paramMap;
      } catch (Exception var6) {
         Exception e = var6;
         throw new BasicServiceException(e);
      }
   }

   private static Map<String, String> transToMap(String obj, String queryField) {
      Map<String, String> paramMap = new HashMap();

      try {
         JSONObject jsonObject = JSONObject.parseObject(obj);
         String[] queryFields = queryField.split(":");

         for(int i = 2; i < queryFields.length; ++i) {
            String value = jsonObject.getString(queryFields[i]);
            if (value == null) {
               throw new Exception("查询条件" + queryFields[i] + "的值为空,刷新该对象的缓存失败！");
            }

            paramMap.put(queryFields[i], value.toString());
         }

         return paramMap;
      } catch (Exception var7) {
         Exception e = var7;
         throw new BasicServiceException(e);
      }
   }

   public static void refresh(String key, Object obj) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         int newVersion = genVersionByConfCode(jsonObject);
         String queryFields = jsonObject.getString("queryField");
         SimplePropertyPreFilter simplePropertyPreFilter = getFilterProperty(queryFields, obj);
         String jsonStr = JSONObject.toJSONString(obj, simplePropertyPreFilter, new SerializerFeature[0]);
         List<String> jsonObjs = new ArrayList();
         jsonObjs.add(jsonStr);
         jsonStr = getJsonStr(queryFields, jsonObjs);
         Map<String, Object> map = new HashMap();
         map.put("version", newVersion);
         map.put("list", jsonStr);
         String queryConditon = jsonObject.getString("queryCondition");
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         Map<String, String> condition = transToMap(obj, queryConditon);
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         if (redisClient.exists(redisKey)) {
            Long ttl = redisClient.ttl(redisKey);
            if (ttl > 0L) {
               redisClient.setex(redisKey, Math.toIntExact(ttl), JSONObject.toJSONString(map));
               return;
            }
         }

         redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
      } catch (Exception var18) {
         Exception e = var18;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }

   }

   public static void refresh(String key, List<? extends BasicModel> objs) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         int newVersion = genVersionByConfCode(jsonObject);
         String queryConditon = jsonObject.getString("queryCondition");
         Map<String, String> condition = transToMap(objs.get(0), queryConditon);
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         String queryFields = jsonObject.getString("queryField");
         SimplePropertyPreFilter simplePropertyPreFilter = getFilterProperty(queryFields, objs.get(0));
         String jsonStr = JSONObject.toJSONString(objs, simplePropertyPreFilter, new SerializerFeature[0]);
         Map<String, Object> map = new HashMap();
         map.put("version", newVersion);
         map.put("list", jsonStr);
         if (redisClient.exists(redisKey)) {
            Long ttl = redisClient.ttl(redisKey);
            if (ttl > 0L) {
               redisClient.setex(redisKey, Math.toIntExact(ttl), JSONObject.toJSONString(map));
               return;
            }
         }

         redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
      } catch (Exception var17) {
         Exception e = var17;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }
   }

   public static void append(String key, Object obj) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         String queryConditon = jsonObject.getString("queryCondition");
         Map<String, String> condition = transToMap(obj, queryConditon);
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         if (redisClient.exists(redisKey)) {
            redisClient.del(redisKey);
         }
      } catch (Exception var11) {
         Exception e = var11;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }

   }

   public static void refreshByStr(String key, String jsonObj) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         int newVersion = genVersionByConfCode(jsonObject);
         String queryFields = jsonObject.getString("queryField");
         List<String> jsonObjs = new ArrayList();
         jsonObjs.add(jsonObj);
         String jsonStr = getJsonStr(queryFields, jsonObjs);
         Map<String, Object> map = new HashMap();
         map.put("version", newVersion);
         map.put("list", jsonStr);
         String queryConditon = jsonObject.getString("queryCondition");
         Map<String, String> condition = transToMap(jsonObj, queryConditon);
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         if (redisClient.exists(redisKey)) {
            Long ttl = redisClient.ttl(redisKey);
            if (ttl > 0L) {
               redisClient.setex(redisKey, Math.toIntExact(ttl), JSONObject.toJSONString(map));
               return;
            }
         }

         redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
      } catch (Exception var17) {
         Exception e = var17;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }
   }

   public static void refreshByStr(String key, List<String> jsonObjs) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         int newVersion = genVersionByConfCode(jsonObject);
         String queryFields = jsonObject.getString("queryField");
         String jsonStr = getJsonStr(queryFields, jsonObjs);
         Map<String, Object> map = new HashMap();
         map.put("version", newVersion);
         map.put("list", jsonStr);
         String queryConditon = jsonObject.getString("queryCondition");
         Map<String, String> condition = transToMap((String)jsonObjs.get(0), queryConditon);
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         if (redisClient.exists(redisKey)) {
            Long ttl = redisClient.ttl(redisKey);
            if (ttl > 0L) {
               redisClient.setex(redisKey, Math.toIntExact(ttl), JSONObject.toJSONString(map));
               return;
            }
         }

         redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
      } catch (Exception var16) {
         Exception e = var16;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }

   }

   public static String getJsonStr(String queryField, List<String> jsonObjs) throws Exception {
      List<Map<String, Object>> lists = new ArrayList();

      try {
         String[] queryFields = queryField.split(",");
         Iterator var5 = jsonObjs.iterator();

         while(var5.hasNext()) {
            String jsonObj = (String)var5.next();
            Map<String, Object> param = new HashMap();
            JSONObject jsonObject = JSONObject.parseObject(jsonObj);

            for(int i = 0; i < queryFields.length; ++i) {
               Object value = jsonObject.get(queryFields[i]);
               if (value != null) {
                  param.put(queryFields[i], value);
               }
            }

            lists.add(param);
         }

         String result = JSONObject.toJSONString(lists);
         return result;
      } catch (Exception var11) {
         Exception e = var11;
         throw new Exception(e.getMessage());
      }
   }

   public static SimplePropertyPreFilter getFilterProperty(String queryFields, Object obj) throws Exception {
      SimplePropertyPreFilter filter = new SimplePropertyPreFilter(obj.getClass(), new String[0]);

      try {
         if (!StringUtils.isBlank(queryFields)) {
            String[] queryFieldsIn = queryFields.split(",");
            String[] var4 = queryFieldsIn;
            int var5 = queryFieldsIn.length;

            for(int var6 = 0; var6 < var5; ++var6) {
               String in = var4[var6];
               filter.getIncludes().add(in);
            }
         }

         return filter;
      } catch (Exception var8) {
         Exception e = var8;
         throw e;
      }
   }

   public static void refreshNewTime(String key, Object obj) throws Exception {
      LinkRedisClient redisClient = null;

      try {
         JSONObject jsonObject = getConfigByKey(key);
         String redisDbName = jsonObject.getString("redisDbName");
         redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
         int newVersion = genVersionByConfCode(jsonObject);
         String queryFields = jsonObject.getString("queryField");
         SimplePropertyPreFilter simplePropertyPreFilter = getFilterProperty(queryFields, obj);
         String jsonStr = JSONObject.toJSONString(obj, simplePropertyPreFilter, new SerializerFeature[0]);
         List<String> jsonObjs = new ArrayList();
         jsonObjs.add(jsonStr);
         jsonStr = getJsonStr(queryFields, jsonObjs);
         Map<String, Object> map = new HashMap();
         map.put("version", newVersion);
         map.put("list", jsonStr);
         String queryConditon = jsonObject.getString("queryCondition");
         Map<String, String> condition = transToMap(obj, queryConditon);
         String redisKey = genRedisKeyByConf(jsonObject, condition);
         redisClient.setex(redisKey, RedisCache.getCacheTime(), JSONObject.toJSONString(map));
      } catch (Exception var17) {
         Exception e = var17;
         throw new Exception(e.getMessage());
      } finally {
         RedisUtil.returnResource(redisClient);
      }

   }

   public static void deleteObj(List<String> keys, Object obj) throws Exception {
      Iterator var2 = keys.iterator();

      while(var2.hasNext()) {
         String key = (String)var2.next();
         LinkRedisClient redisClient = null;

         try {
            JSONObject jsonObject = getConfigByKey(key);
            String redisDbName = jsonObject.getString("redisDbName");
            redisClient = RedisUtil.getJedis(RedisCache.getRedisDbNameByStr(redisDbName));
            String queryConditon = jsonObject.getString("queryCondition");
            Map<String, String> condition = transToMap(obj, queryConditon);
            String redisKey = genRedisKeyByConf(jsonObject, condition);
            if (redisClient.exists(redisKey)) {
               redisClient.del(redisKey);
            }
         } catch (Exception var13) {
            Exception e = var13;
            throw new Exception(e.getMessage());
         } finally {
            RedisUtil.returnResource(redisClient);
         }
      }

   }
}
